@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::Koha;
 #ABSTRACT: Class exposing info about a Koha instance.
-$Koha::Contrib::Tamil::Koha::VERSION = '0.065';
+$Koha::Contrib::Tamil::Koha::VERSION = '0.066';
 use Moose;
 
 use Modern::Perl;
@@ -163,7 +163,7 @@ sub zauth {
 sub get_biblio_marc {
     my ( $self, $id ) = @_; 
     my $sth = $self->dbh->prepare(
-        "SELECT marcxml FROM biblioitems WHERE biblionumber=? ");
+        "SELECT metadata FROM biblio_metadata WHERE biblionumber=? ");
     $sth->execute( $id );
     my ($marcxml) = $sth->fetchrow;
     return unless $marcxml;
@@ -210,7 +210,7 @@ Koha::Contrib::Tamil::Koha - Class exposing info about a Koha instance.
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 ATTRIBUTES
 
@@ -262,7 +262,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Fréderic Démians.
+This software is Copyright (c) 2021 by Fréderic Démians.
 
 This is free software, licensed under:
 
